; ===========================================================================
; $Id: varlist_1no.pro,v 1.1 2001/10/22 18:48:46 jlin Exp $
;
; File Description:  This file contains only the procedure varlist.
; ===========================================================================


;--------------------------------------------------------------------------
;                            procedure varlist
;
; Purpose:
;   Takes a given QTCM1 variable and returns the number of the variable
;   in the output list, a unit conversion multiplier, the units of the
;   variable, and the units of the square of the variable.
;
;   NB:  Secondary values are NOT listed in this file.  Thus, if NFIELD
;   equals 1, and the variable name isn't found in this procedure, an
;   error is returned.
;
;   Philosophy:  I try to control as much of the secondary field values
;   as I can via VARTYPEIT.  I try to control as much of the primary 
;   field values as I can via VARLIST.
;
;   This version of the procedure operates on an output file for which
;   NFIELD=1, ivar=1, convmult=1, and units are not given.  gridloctype
;   is set to 'Not Given'
;
; Parameters In:
;   varname       name of variable (string)
;
; Parameters Out:
;   ivar          number of variable in list (integer)
;   convmult      units conversion multiplier (double)
;   units         units of variable, after convert (string)
;   units2        units of square of variable, after convert (string)
;
; Keywords Passed:
;   NFIELD        Number of fields the calling procedure believes is in
;                 the data file at each time step (keyword required).
;   gridloctype   Type of the location of the grid; 'u' or 'v', etc. on
;                 the staggered Arakawa C-grid (string).  Optional
;                 keyword.
;
; Notes:
; - Written in IDL 5.0.
; - Works with QTCM v2.1 standard output.
; - No user-written procedures called.
; - No common blocks in this procedure.
;
; Revision history:
; - 29 Dec 1999:  Orig. by Johnny Lin, UCLA Dept. of Atmos. Sci.
;                 Based on QTCM1 v2.1 tools varlist_3j1.pro RCSv1.1.
;                 Passed reasonable tests.
; - 4  Jan 2000:  GRIDLOCTYPE added.  Passed minimally reasonable tests.
;--------------------------------------------------------------------------

PRO VARLIST, varname,ivar,convmult,units,units2  $
           , NFIELD=nfield  $
           , GRIDLOCTYPE=gridloctype



;                   --- Error Check and Default Values ---

On_Error, 0
if (ARG_PRESENT(ivar) eq 0)     then Message, 'error--out param missing'
if (ARG_PRESENT(convmult) eq 0) then Message, 'error--out param missing'
if (ARG_PRESENT(units) eq 0)    then Message, 'error--out param missing'
if (ARG_PRESENT(units2) eq 0)   then Message, 'error--out param missing'
if (N_ELEMENTS(nfield) eq 0)    then Message, 'error--need NFIELD'
if (nfield ne 1)                then Message, 'error--NFIELD ne 1'
 
ivar=1
convmult=1.d0
units='Not Given'
units2='Not Given'
if (ARG_PRESENT(gridloctype) eq 1) then gridloctype='Not Given'



return
end     ;=== end procedure ===


; ========== end file ==========
